@@ -151,12 +151,48 @@ def order_validation(order):
     result = True
 
     if len(order) == 3 and type(order)==list:
-        order = [x.upper() for x in order]        
-        for item in order:
-            if item == 'MM' or item == 'DD' or item == 'YYYY':
-                pass
+        order = [x.upper() for x in order] 
+        if order[0] == 'MM':
+            if order[1] == 'DD':
+                if order[2] == 'YYYY':
+                    pass
+                else:
+                    result = 'Invalid order'
+            elif order[1] == 'YYYY':
+                if order[2] == 'MM':
+                    pass
+                else:
+                    result = 'Invalid order'
             else:
-                result = 'Invalid order '
+                result = 'Invalid order'
+        
+        if order[0] == 'DD':
+            if order[1] == 'MM':
+                if order[2] == 'YYYY':
+                    pass
+                else:
+                    result = 'Invalid order'
+            elif order[1] == 'YYYY':
+                if order[2] == 'MM':
+                    pass
+                else:
+                    result = 'Invalid order'
+            else:
+                result = 'Invalid order'
+        
+        if order[0] == 'YYYY':
+            if order[1] == 'MM':
+                if order[2] == 'DD':
+                    pass
+                else:
+                    result = 'Invalid order'
+            elif order[1] == 'DD':
+                if order[2] == 'MM':
+                    pass
+                else:
+                    result = 'Invalid order'
+            else:
+                result = 'Invalid order'
     else:
         result = 'Invalid order'
     return result
